# OE1100
# UI script adds checkbox  on the O/E order entry screen. opt fldname PREFERCUST
#
###################################################################################################################################################
# Copyright 2020 Orchid Systems 
# -----------------------------
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an as is basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
###################################################################################################################################################

from accpac import *

def main(args):
	MyUI()

class MyUI(UI):
	def __init__(self):
		UI.__init__(self)
		self.doNotUpdateOptField = False
		self.createScreen()

	def createScreen(self):
		self.getControlInfo("form|afeOEORDHautotaxcal1|stbOrderEntry", self.onControlInfo)
		self.getHostControl("stbOrderEntry").setOnClick(self.onTabClick)
		
		self.dsH = self.openDataSource("adsOEORDH")
		self.dsH.onAfter = self.dsH_onAfter
		
		self.dsHO = self.openDataSource("dsOEORDHO")
		self.dsHO.onAfter = self.dsHO_onAfter
		
		self.show()

	def onControlInfo(self, info):
		f = info.find("form")

		b = info.findByCaption("Calc. Tax")
		tab = info.find("stbOrderEntry")

		self.dsH = self.openDataSource("adsOEORDH")
		self.dsHO = self.openDataSource("dsOEORDHO")

		f = self.addCheckBox("PREFERCUST")
		f.setValue("0")
		f.setText("Preferred")
		f.left = tab.left + b.left + b.width + 50
		f.top = tab.top + b.top
		f.onChange = self.onChange_myOpField
		f.disable()	# disable the tickbox for now.
		self.myOptField = f
		
		self.show()

	def dsH_onAfter(self, eventName, fieldName, value):
	
		if eventName == "FETCH" or eventName.startswith("GO") or eventName == "READ" or eventName == "INIT" or eventName == "KEYPUT":
			# We are moving into a new record, so we need to update the checkbox.
			# Note: the KEYPUT event happens when you use the finder to choose a sales order.
			self.setTimeout(10, self.myTimeout)
			self.show()	# Don't forget to this!
			
		if eventName == "PUT":
			if fieldName == "CUSTOMER":
				# don't bother using value to check the value.
				# on the onAfter event, value is always blank.
				# so you need to get the value from the datasource.
				# use the timer function to wait for the view to finish with the Customer field.
				self.setTimeout(10, self.myTimeout)
				self.show()	# Don't forget to this!
				
	def myTimeout(self):
		if self.dsH.get("CUSTOMER").strip() == "":
			self.myOptField.disable()
		else:
			self.myOptField.enable()
			self.fillOptFieldValue("PREFERCUST")

		self.show()
		
	def dsHO_onAfter(self, eventName, fieldName, value):
		
		# After the optional field is updated, we need to update the checkbox.
		if eventName == "UPDATE" or eventName == "INSERT":
			optfldName = self.dsHO.get("OPTFIELD").strip()
			self.fillOptFieldValue(optfldName)
		
	def onTabClick(self, tab):
		
		if tab == 0:
			self.myOptField.show()
		else:
			self.myOptField.hide()
			
		return None
		
	def onChange_myOpField(self, newValue):
		
		self.dsHO.put("OPTFIELD", "PREFERCUST")
		if self.dsHO.read() == 0:
			currValue = self.dsHO.get("VALUE")
			# compare current and new.
			#showMessageBox(str(currValue).strip() + " vs " + str(newValue).strip())
			if str(currValue).strip() != str(newValue).strip():
				#showMessageBox("update")
				self.dsHO.put("VALUE", newValue)
				self.dsHO.update()
		else:
			self.addOptionalField("PREFERCUST", newValue)

		self.dsHO.refreshFields()
		
			
	def addOptionalField(self, optfield, value):
		r = 0
		if (r == 0):
			r = self.dsHO.recordGenerate()
		if (r == 0):
			r = self.dsHO.put("OPTFIELD", optfield)
		if (r == 0):
			r = self.dsHO.put("VALUE", value)
		if (r == 0):
			r = self.dsHO.insert()
		return r
			
	def fillOptFieldValue(self, optFld):
		if optFld == "PREFERCUST":
			self.dsHO.put("OPTFIELD", "PREFERCUST")
			if self.dsHO.read() == 0:
				#self.doNotUpdateOptField = False
				optVal = self.dsHO.get("VALUE")
				self.myOptField.setValue(optVal)
				
	
